@@ -6,32 +6,33 @@
  * @package PhpMyAdmin
  */
 
-chdir('..');
+if (!defined('TESTSUITE')) {
+    chdir('..');
 
-// Send correct type:
-header('Content-Type: text/javascript; charset=UTF-8');
+    // Send correct type:
+    header('Content-Type: text/javascript; charset=UTF-8');
 
-// Cache output in client - the nocache query parameter makes sure that this
-// file is reloaded when config changes
-header('Expires: ' . gmdate('D, d M Y H:i:s', time() + 3600) . ' GMT');
+    // Cache output in client - the nocache query parameter makes sure that this
+    // file is reloaded when config changes
+    header('Expires: ' . gmdate('D, d M Y H:i:s', time() + 3600) . ' GMT');
+
+    // Avoid loading the full common.inc.php because this would add many
+    // non-js-compatible stuff like DOCTYPE
+    define('PMA_MINIMUM_COMMON', true);
+    define('PMA_PATH_TO_BASEDIR', '../');
+    require_once './libraries/common.inc.php';
+    // Close session early as we won't write anything there
+    session_write_close();
+}
 
-// Avoid loading the full common.inc.php because this would add many
-// non-js-compatible stuff like DOCTYPE
-define('PMA_MINIMUM_COMMON', true);
-define('PMA_PATH_TO_BASEDIR', '../');
-require_once './libraries/common.inc.php';
-// Close session early as we won't write anything there
-session_write_close();
 // But this one is needed for PMA_escapeJsString()
 require_once './libraries/js_escape.lib.php';
-require_once './libraries/Util.class.php';
 
-require_once './libraries/OutputBuffering.class.php';
-$buffer = PMA_OutputBuffering::getInstance();
+$buffer = PMA\libraries\OutputBuffering::getInstance();
 $buffer->start();
 register_shutdown_function(
     function () {
-        echo PMA_OutputBuffering::getInstance()->getContents();
+        echo PMA\libraries\OutputBuffering::getInstance()->getContents();
     }
 );
 
@@ -43,26 +44,45 @@ if ($cfg['AllowUserDropDatabase']) {
 /* For confirmations */
 $js_messages['strConfirm'] = __('Confirm');
 $js_messages['strDoYouReally'] = __('Do you really want to execute "%s"?');
-$js_messages['strDropDatabaseStrongWarning'] = __('You are about to DESTROY a complete database!');
-$js_messages['strDropTableStrongWarning'] = __('You are about to DESTROY a complete table!');
-$js_messages['strTruncateTableStrongWarning'] = __('You are about to TRUNCATE a complete table!');
+$js_messages['strDropDatabaseStrongWarning']
+    = __('You are about to DESTROY a complete database!');
+$js_messages['strDropTableStrongWarning']
+    = __('You are about to DESTROY a complete table!');
+$js_messages['strTruncateTableStrongWarning']
+    = __('You are about to TRUNCATE a complete table!');
 $js_messages['strDeleteTrackingData'] = __('Delete tracking data for this table?');
-$js_messages['strDeleteTrackingDataMultiple'] = __('Delete tracking data for these tables?');
-$js_messages['strDeleteTrackingVersion'] = __('Delete tracking data for this version?');
-$js_messages['strDeleteTrackingVersionMultiple'] = __('Delete tracking data for these versions?');
+$js_messages['strDeleteTrackingDataMultiple']
+    = __('Delete tracking data for these tables?');
+$js_messages['strDeleteTrackingVersion']
+    = __('Delete tracking data for this version?');
+$js_messages['strDeleteTrackingVersionMultiple']
+    = __('Delete tracking data for these versions?');
 $js_messages['strDeletingTrackingEntry'] = __('Delete entry from tracking report?');
 $js_messages['strDeletingTrackingData'] = __('Deleting tracking data');
 $js_messages['strDroppingPrimaryKeyIndex'] = __('Dropping Primary Key/Index');
 $js_messages['strDroppingForeignKey'] = __('Dropping Foreign key.');
-$js_messages['strOperationTakesLongTime'] = __('This operation could take a long time. Proceed anyway?');
-$js_messages['strDropUserGroupWarning'] = __('Do you really want to delete user group "%s"?');
-$js_messages['strConfirmDeleteQBESearch'] = __('Do you really want to delete the search "%s"?');
-$js_messages['strConfirmNavigation'] = __('You have unsaved changes; are you sure you want to leave this page?');
-$js_messages['strDropUserWarning'] = __('Do you really want to revoke the selected user(s) ?');
-$js_messages['strDeleteCentralColumnWarning'] = __('Do you really want to delete this central column?');
-$js_messages['strDropRTEitems'] = __('Do you really want to delete the selected items?');
-$js_messages['strDropPartitionWarning'] = __('Do you really want to DROP the selected partition(s)? This will also DELETE the data related to the selected partition(s)!');
-$js_messages['strTruncatePartitionWarning'] = __('Do you really want to TRUNCATE the selected partition(s)?');
+$js_messages['strOperationTakesLongTime']
+    = __('This operation could take a long time. Proceed anyway?');
+$js_messages['strDropUserGroupWarning']
+    = __('Do you really want to delete user group "%s"?');
+$js_messages['strConfirmDeleteQBESearch']
+    = __('Do you really want to delete the search "%s"?');
+$js_messages['strConfirmNavigation']
+    = __('You have unsaved changes; are you sure you want to leave this page?');
+$js_messages['strDropUserWarning']
+    = __('Do you really want to revoke the selected user(s) ?');
+$js_messages['strDeleteCentralColumnWarning']
+    = __('Do you really want to delete this central column?');
+$js_messages['strDropRTEitems']
+    = __('Do you really want to delete the selected items?');
+$js_messages['strDropPartitionWarning'] = __(
+    'Do you really want to DROP the selected partition(s)? This will also DELETE ' .
+    'the data related to the selected partition(s)!'
+);
+$js_messages['strTruncatePartitionWarning']
+    = __('Do you really want to TRUNCATE the selected partition(s)?');
+$js_messages['strRemovePartitioningWarning']
+    = __('Do you really want to remove partitioning?');
 $js_messages['strResetSlaveWarning'] = __('Do you really want to RESET SLAVE?');
 $js_messages['strChangeColumnCollation'] = __(
     'This operation will attempt to convert your data to the new collation. In '
@@ -75,15 +95,17 @@ $js_messages['strChangeColumnCollation'] = __(
     . '<br/><br/>'
     . __('Are you sure you wish to change the collation and convert the data?');
 $js_messages['strChangeAllColumnCollationsWarning'] = __(
-    'Through this operation, MySQL attempts to map the data values between collations. '
-    . 'If the character sets are incompatible, '
-    . 'there may be data loss and this lost data may <b>NOT</b> be recoverable simply '
-    . 'by changing back the column collation(s).'
-    . '<b> To convert existing data, it is suggested to use the column(s) editing feature '
-    . '(the "Change" Link) on the table structure page. </b>'
+    'Through this operation, MySQL attempts to map the data values between '
+    . 'collations. If the character sets are incompatible, there may be data loss '
+    . 'and this lost data may <b>NOT</b> be recoverable simply by changing back the '
+    . 'column collation(s). <b>To convert existing data, it is suggested to use the '
+    . 'column(s) editing feature (the "Change" Link) on the table structure page. '
+    . '</b>'
 )
 . '<br/><br/>'
-. __('Are you sure you wish to change all the column collations and convert the data?');
+. __(
+    'Are you sure you wish to change all the column collations and convert the data?'
+);
 
 /* For modal dialog buttons */
 $js_messages['strSaveAndClose'] = __('Save & close');
@@ -142,8 +164,14 @@ $js_messages['strDecimalSeparator'] = __('.');
 $js_messages['strChartConnectionsTitle'] = __('Connections / Processes');
 
 /* server status monitor */
-$js_messages['strIncompatibleMonitorConfig'] = __('Local monitor configuration incompatible!');
-$js_messages['strIncompatibleMonitorConfigDescription'] = __('The chart arrangement configuration in your browsers local storage is not compatible anymore to the newer version of the monitor dialog. It is very likely that your current configuration will not work anymore. Please reset your configuration to default in the <i>Settings</i> menu.');
+$js_messages['strIncompatibleMonitorConfig']
+    = __('Local monitor configuration incompatible!');
+$js_messages['strIncompatibleMonitorConfigDescription'] = __(
+    'The chart arrangement configuration in your browsers local storage is not '
+    . 'compatible anymore to the newer version of the monitor dialog. It is very '
+    . 'likely that your current configuration will not work anymore. Please reset '
+    . 'your configuration to default in the <i>Settings</i> menu.'
+);
 
 $js_messages['strQueryCacheEfficiency'] = __('Query cache efficiency');
 $js_messages['strQueryCacheUsage'] = __('Query cache usage');
@@ -186,7 +214,8 @@ $js_messages['strTraffic'] = __('Traffic');
 $js_messages['strSettings'] = __('Settings');
 $js_messages['strAddChart'] = __('Add chart to grid');
 $js_messages['strClose'] = __('Close');
-$js_messages['strAddOneSeriesWarning'] = __('Please add at least one variable to the series!');
+$js_messages['strAddOneSeriesWarning']
+    = __('Please add at least one variable to the series!');
 $js_messages['strNone'] = __('None');
 $js_messages['strResumeMonitor'] = __('Resume monitor');
 $js_messages['strPauseMonitor'] = __('Pause monitor');
@@ -199,9 +228,16 @@ $js_messages['strSlowLogOn'] = __('slow_query_log is enabled.');
 $js_messages['strBothLogOff'] = __('slow_query_log and general_log are disabled.');
 $js_messages['strLogOutNotTable'] = __('log_output is not set to TABLE.');
 $js_messages['strLogOutIsTable'] = __('log_output is set to TABLE.');
-$js_messages['strSmallerLongQueryTimeAdvice'] = __('slow_query_log is enabled, but the server logs only queries that take longer than %d seconds. It is advisable to set this long_query_time 0-2 seconds, depending on your system.');
+$js_messages['strSmallerLongQueryTimeAdvice'] = __(
+    'slow_query_log is enabled, but the server logs only queries that take longer '
+    . 'than %d seconds. It is advisable to set this long_query_time 0-2 seconds, '
+    . 'depending on your system.'
+);
 $js_messages['strLongQueryTimeSet'] = __('long_query_time is set to %d second(s).');
-$js_messages['strSettingsAppliedGlobal'] = __('Following settings will be applied globally and reset to default on server restart:');
+$js_messages['strSettingsAppliedGlobal'] = __(
+    'Following settings will be applied globally and reset to default on server '
+    . 'restart:'
+);
 /* l10n: %s is FILE or TABLE */
 $js_messages['strSetLogOutput'] = __('Set log_output to %s');
 /* l10n: Enable in this context means setting a status variable to ON */
@@ -229,15 +265,26 @@ $js_messages['strServerLogError'] = __(
     'The database name is not known for this query in the server\'s logs.'
 );
 $js_messages['strAnalysingLogsTitle'] = __('Analysing logs');
-$js_messages['strAnalysingLogs'] = __('Analysing & loading logs. This may take a while.');
+$js_messages['strAnalysingLogs']
+    = __('Analysing & loading logs. This may take a while.');
 $js_messages['strCancelRequest'] = __('Cancel request');
-$js_messages['strCountColumnExplanation'] = __('This column shows the amount of identical queries that are grouped together. However only the SQL query itself has been used as a grouping criteria, so the other attributes of queries, such as start time, may differ.');
-$js_messages['strMoreCountColumnExplanation'] = __('Since grouping of INSERTs queries has been selected, INSERT queries into the same table are also being grouped together, disregarding of the inserted data.');
-$js_messages['strLogDataLoaded'] = __('Log data loaded. Queries executed in this time span:');
+$js_messages['strCountColumnExplanation'] = __(
+    'This column shows the amount of identical queries that are grouped together. '
+    . 'However only the SQL query itself has been used as a grouping criteria, so '
+    . 'the other attributes of queries, such as start time, may differ.'
+);
+$js_messages['strMoreCountColumnExplanation'] = __(
+    'Since grouping of INSERTs queries has been selected, INSERT queries into the '
+    . 'same table are also being grouped together, disregarding of the inserted '
+    . 'data.'
+);
+$js_messages['strLogDataLoaded']
+    = __('Log data loaded. Queries executed in this time span:');
 
 $js_messages['strJumpToTable'] = __('Jump to Log table');
 $js_messages['strNoDataFoundTitle'] = __('No data found');
-$js_messages['strNoDataFound'] = __('Log analysed, but no data found in this time span.');
+$js_messages['strNoDataFound']
+    = __('Log analysed, but no data found in this time span.');
 
 $js_messages['strAnalyzing'] = __('Analyzing…');
 $js_messages['strExplainOutput'] = __('Explain output');
@@ -253,13 +300,18 @@ $js_messages['strFiltersForLogTable'] = __('Log table filter options');
 /* l10n: Filter as in "Start Filtering" */
 $js_messages['strFilter'] = __('Filter');
 $js_messages['strFilterByWordRegexp'] = __('Filter queries by word/regexp:');
-$js_messages['strIgnoreWhereAndGroup'] = __('Group queries, ignoring variable data in WHERE clauses');
+$js_messages['strIgnoreWhereAndGroup']
+    = __('Group queries, ignoring variable data in WHERE clauses');
 $js_messages['strSumRows'] = __('Sum of grouped rows:');
 $js_messages['strTotal'] = __('Total:');
 
 $js_messages['strLoadingLogs'] = __('Loading logs');
 $js_messages['strRefreshFailed'] = __('Monitor refresh failed');
-$js_messages['strInvalidResponseExplanation'] = __('While requesting new chart data the server returned an invalid response. This is most likely because your session expired. Reloading the page and reentering your credentials should help.');
+$js_messages['strInvalidResponseExplanation'] = __(
+    'While requesting new chart data the server returned an invalid response. This '
+    . 'is most likely because your session expired. Reloading the page and '
+    . 'reentering your credentials should help.'
+);
 $js_messages['strReloadPage'] = __('Reload page');
 
 $js_messages['strAffectedRows'] = __('Affected rows:');
@@ -267,10 +319,13 @@ $js_messages['strAffectedRows'] = __('Affected rows:');
 $js_messages['strFailedParsingConfig'] = __(
     'Failed parsing config file. It doesn\'t seem to be valid JSON code.'
 );
-$js_messages['strFailedBuildingGrid'] = __('Failed building chart grid with imported config. Resetting to default config…');
+$js_messages['strFailedBuildingGrid'] = __(
+    'Failed building chart grid with imported config. Resetting to default config…'
+);
 $js_messages['strImport'] = __('Import');
 $js_messages['strImportDialogTitle'] = __('Import monitor configuration');
-$js_messages['strImportDialogMessage'] = __('Please select the file you want to import.');
+$js_messages['strImportDialogMessage']
+    = __('Please select the file you want to import.');
 $js_messages['strNoImportFile'] = __('No files available on server for import!');
 
 $js_messages['strAnalyzeQuery'] = __('Analyse query');
@@ -288,6 +343,7 @@ $js_messages['strTest'] = __('Test');
 
 /* For query editor */
 $js_messages['strFormatting'] = __('Formatting SQL…');
+$js_messages['strNoParam'] = __('No parameters found!');
 
 /* For inline query editing */
 $js_messages['strGo'] = __('Go');
@@ -331,7 +387,8 @@ $js_messages['strBrowsing'] = __('Browsing');
 $js_messages['strDeleting'] = __('Deleting');
 
 /* For db_routines.js */
-$js_messages['MissingReturn'] = __('The definition of a stored function must contain a RETURN statement!');
+$js_messages['MissingReturn']
+    = __('The definition of a stored function must contain a RETURN statement!');
 $js_messages['strExport'] = __('Export');
 
 /* For ENUM/SET editor*/
@@ -342,7 +399,9 @@ $js_messages['enum_hint'] =__('Enter each value in a separate field.');
 $js_messages['enum_addValue'] =__('Add %d value(s)');
 
 /* For import.js */
-$js_messages['strImportCSV'] = __('Note: If the file contains multiple tables, they will be combined into one.');
+$js_messages['strImportCSV'] = __(
+    'Note: If the file contains multiple tables, they will be combined into one.'
+);
 
 /* For sql.js */
 $js_messages['strHideQueryBox'] = __('Hide query box');
@@ -358,30 +417,45 @@ $js_messages['strBookmarkVariable'] = __('Variable %d:');
 $js_messages['pickColumn'] = __('Pick');
 $js_messages['pickColumnTitle'] = __('Column selector');
 $js_messages['searchList'] = __('Search this list');
-$js_messages['strEmptyCentralList'] = __('No columns in the central list. Make sure the Central columns list for database %s has columns that are not present in the current table.');
+$js_messages['strEmptyCentralList'] = __(
+    'No columns in the central list. Make sure the Central columns list for '
+    . 'database %s has columns that are not present in the current table.'
+);
 $js_messages['seeMore'] = __('See more');
 $js_messages['confirmTitle'] = __('Are you sure?');
-$js_messages['makeConsistentMessage'] = __('This action may change some of the columns definition.<br/>Are you sure you want to continue?');
+$js_messages['makeConsistentMessage'] = __(
+    'This action may change some of the columns definition.<br/>Are you sure you '
+    . 'want to continue?'
+);
 $js_messages['strContinue'] = __('Continue');
 
 /** For normalization */
 $js_messages['strAddPrimaryKey'] = __('Add primary key');
 $js_messages['strPrimaryKeyAdded'] = __('Primary key added.');
 $js_messages['strToNextStep'] = __('Taking you to next step…');
-$js_messages['strFinishMsg'] = __("The first step of normalization is complete for table '%s'.");
+$js_messages['strFinishMsg']
+    = __("The first step of normalization is complete for table '%s'.");
 $js_messages['strEndStep'] = __("End of step");
 $js_messages['str2NFNormalization'] = __('Second step of normalization (2NF)');
 $js_messages['strDone'] = __('Done');
 $js_messages['strConfirmPd'] = __('Confirm partial dependencies');
 $js_messages['strSelectedPd'] = __('Selected partial dependencies are as follows:');
-$js_messages['strPdHintNote'] = __('Note: a, b -> d,f implies values of columns a and b combined together can determine values of column d and column f.');
+$js_messages['strPdHintNote'] = __(
+    'Note: a, b -> d,f implies values of columns a and b combined together can '
+    . 'determine values of column d and column f.'
+);
 $js_messages['strNoPdSelected'] = __('No partial dependencies selected!');
 $js_messages['strBack'] = __('Back');
-$js_messages['strShowPossiblePd'] = __('Show me the possible partial dependencies based on data in the table');
+$js_messages['strShowPossiblePd']
+    = __('Show me the possible partial dependencies based on data in the table');
 $js_messages['strHidePd'] = __('Hide partial dependencies list');
-$js_messages['strWaitForPd'] = __('Sit tight! It may take few seconds depending on data size and column count of the table.');
+$js_messages['strWaitForPd'] = __(
+    'Sit tight! It may take few seconds depending on data size and column count of '
+    . 'the table.'
+);
 $js_messages['strStep'] = __('Step');
-$js_messages['strMoveRepeatingGroup'] = '<ol><b>' . __('The following actions will be performed:') . '</b>'
+$js_messages['strMoveRepeatingGroup']
+    = '<ol><b>' . __('The following actions will be performed:') . '</b>'
     . '<li>' . __('DROP columns %s from the table %s') . '</li>'
     . '<li>' . __('Create the following table') . '</li>';
 $js_messages['strNewTablePlaceholder'] = 'Enter new table name';
@@ -455,7 +529,8 @@ $js_messages['strLockToolTip'] = __(
 /* Designer (js/pmd/move.js) */
 $js_messages['strSelectReferencedKey'] = __('Select referenced key');
 $js_messages['strSelectForeignKey'] = __('Select Foreign Key');
-$js_messages['strPleaseSelectPrimaryOrUniqueKey'] = __('Please select the primary key or a unique key!');
+$js_messages['strPleaseSelectPrimaryOrUniqueKey']
+    = __('Please select the primary key or a unique key!');
 $js_messages['strChangeDisplay'] = __('Choose column to display');
 $js_messages['strLeavingDesigner'] = __(
     'You haven\'t saved the changes in the layout. They will be lost if you'
@@ -469,7 +544,8 @@ $js_messages['strDeletePage'] = __('Delete page');
 $js_messages['strUntitled'] = __('Untitled');
 $js_messages['strSelectPage'] = __('Please select a page to continue');
 $js_messages['strEnterValidPageName'] = __('Please enter a valid page name');
-$js_messages['strLeavingPage'] = __('Do you want to save the changes to the current page?');
+$js_messages['strLeavingPage']
+    = __('Do you want to save the changes to the current page?');
 $js_messages['strSuccessfulPageDelete'] = __('Successfully deleted the page');
 $js_messages['strExportRelationalSchema'] = __('Export relational schema');
 $js_messages['strModificationSaved'] = __('Modifications have been saved');
@@ -481,19 +557,33 @@ $js_messages['strSubmit'] = __('Submit');
 
 /* For makegrid.js (column reordering, show/hide column, grid editing) */
 $js_messages['strCellEditHint'] = __('Press escape to cancel editing.');
-$js_messages['strSaveCellWarning'] = __('You have edited some data and they have not been saved. Are you sure you want to leave this page before saving the data?');
+$js_messages['strSaveCellWarning'] = __(
+    'You have edited some data and they have not been saved. Are you sure you want '
+    . 'to leave this page before saving the data?'
+);
 $js_messages['strColOrderHint'] = __('Drag to reorder.');
 $js_messages['strSortHint'] = __('Click to sort results by this column.');
-$js_messages['strMultiSortHint'] = __('Shift+Click to add this column to ORDER BY clause or to toggle ASC/DESC.<br />- Ctrl+Click or Alt+Click (Mac: Shift+Option+Click) to remove column from ORDER BY clause');
+$js_messages['strMultiSortHint'] = __(
+    'Shift+Click to add this column to ORDER BY clause or to toggle ASC/DESC.'
+    . '<br />- Ctrl+Click or Alt+Click (Mac: Shift+Option+Click) to remove column '
+    . 'from ORDER BY clause'
+);
 $js_messages['strColMarkHint'] = __('Click to mark/unmark.');
 $js_messages['strColNameCopyHint'] = __('Double-click to copy column name.');
 $js_messages['strColVisibHint'] = __(
     'Click the drop-down arrow<br />to toggle column\'s visibility.'
 );
 $js_messages['strShowAllCol'] = __('Show all');
-$js_messages['strAlertNonUnique'] = __('This table does not contain a unique column. Features related to the grid edit, checkbox, Edit, Copy and Delete links may not work after saving.');
-$js_messages['strEnterValidHex'] = __('Please enter a valid hexadecimal string. Valid characters are 0-9, A-F.');
-$js_messages['strShowAllRowsWarning'] = __('Do you really want to see all of the rows? For a big table this could crash the browser.');
+$js_messages['strAlertNonUnique'] = __(
+    'This table does not contain a unique column. Features related to the grid '
+    . 'edit, checkbox, Edit, Copy and Delete links may not work after saving.'
+);
+$js_messages['strEnterValidHex']
+    = __('Please enter a valid hexadecimal string. Valid characters are 0-9, A-F.');
+$js_messages['strShowAllRowsWarning'] = __(
+    'Do you really want to see all of the rows? For a big table this could crash '
+    . 'the browser.'
+);
 $js_messages['strOriginalLength'] = __('Original length');
 
 /** Drag & Drop sql import messages */
@@ -505,20 +595,29 @@ $js_messages['dropImportImportResultHeader'] = __('Import status');
 $js_messages['dropImportDropFiles'] = __('Drop files here');
 $js_messages['dropImportSelectDB'] = __('Select database first');
 
+/* For Print view */
+$js_messages['print'] = __('Print');
+$js_messages['back'] = __('Back');
+
 // this approach does not work when the parameter is changed via user prefs
 switch ($GLOBALS['cfg']['GridEditing']) {
 case 'double-click':
-    $js_messages['strGridEditFeatureHint'] = __('You can also edit most values<br />by double-clicking directly on them.');
+    $js_messages['strGridEditFeatureHint'] = __(
+        'You can also edit most values<br />by double-clicking directly on them.'
+    );
     break;
 case 'click':
-    $js_messages['strGridEditFeatureHint'] = __('You can also edit most values<br />by clicking directly on them.');
+    $js_messages['strGridEditFeatureHint'] = __(
+        'You can also edit most values<br />by clicking directly on them.'
+    );
     break;
 default:
     break;
 }
 $js_messages['strGoToLink'] = __('Go to link:');
 $js_messages['strColNameCopyTitle'] = __('Copy column name.');
-$js_messages['strColNameCopyText'] = __('Right-click the column name to copy it to your clipboard.');
+$js_messages['strColNameCopyText']
+    = __('Right-click the column name to copy it to your clipboard.');
 
 /* password generation */
 $js_messages['strGeneratePassword'] = __('Generate password');
@@ -534,19 +633,16 @@ $js_messages['strHidePanel'] = __('Hide panel');
 $js_messages['strUnhideNavItem'] = __('Show hidden navigation tree items.');
 $js_messages['linkWithMain'] = __('Link with main panel');
 $js_messages['unlinkWithMain'] = __('Unlink from main panel');
-$js_messages['strHoverDbFastFilter'] = __('To filter all databases on server, press Enter after a search term');
-$js_messages['strHoverFastFilter'] = __('To filter all %s in database, press Enter after a search term');
-$js_messages['strTables'] = __('tables');
-$js_messages['strViews'] = __('views');
-$js_messages['strProcedures'] = __('procedures');
-$js_messages['strEvents'] = __('events');
-$js_messages['strFunctions'] = __('functions');
 
 /* microhistory */
-$js_messages['strInvalidPage'] = __('The requested page was not found in the history, it may have expired.');
+$js_messages['strInvalidPage']
+    = __('The requested page was not found in the history, it may have expired.');
 
 /* update */
-$js_messages['strNewerVersion'] = __('A newer version of phpMyAdmin is available and you should consider upgrading. The newest version is %s, released on %s.');
+$js_messages['strNewerVersion'] = __(
+    'A newer version of phpMyAdmin is available and you should consider upgrading. '
+    . 'The newest version is %s, released on %s.'
+);
 /* l10n: Latest available phpMyAdmin version */
 $js_messages['strLatestAvailable'] = __(', latest stable version:');
 $js_messages['strUpToDate'] = __('up to date');
@@ -588,7 +684,10 @@ $js_messages['phpErrorsFound'] = '<div class="error">'
 $js_messages['phpErrorsBeingSubmitted'] = '<div class="error">'
     . __('Some errors have been detected on the server!')
     . '<br/>'
-    . __('As per your settings, they are being submitted currently, please be patient.')
+    . __(
+        'As per your settings, they are being submitted currently, please be '
+        . 'patient.'
+    )
     . '<br/>'
     . '<img src="'
     . ($_SESSION['PMA_Theme']->getImgPath('ajax_clock_small.gif'))
@@ -597,14 +696,22 @@ $js_messages['phpErrorsBeingSubmitted'] = '<div class="error">'
 
 // For console
 $js_messages['strConsoleRequeryConfirm'] = __('Execute this query again?');
-$js_messages['strConsoleDeleteBookmarkConfirm'] = __('Do you really want to delete this bookmark?');
-$js_messages['strConsoleDebugError'] = __('Some error occurred while getting SQL debug info.');
-$js_messages['strConsoleDebugSummary'] = __('%s queries executed %s times in %s seconds.');
+$js_messages['strConsoleDeleteBookmarkConfirm']
+    = __('Do you really want to delete this bookmark?');
+$js_messages['strConsoleDebugError']
+    = __('Some error occurred while getting SQL debug info.');
+$js_messages['strConsoleDebugSummary']
+    = __('%s queries executed %s times in %s seconds.');
 $js_messages['strConsoleDebugArgsSummary'] = __('%s argument(s) passed');
 $js_messages['strConsoleDebugShowArgs'] = __('Show arguments');
 $js_messages['strConsoleDebugHideArgs'] = __('Hide arguments');
 $js_messages['strConsoleDebugTimeTaken'] = __('Time taken:');
-$js_messages['strNoLocalStorage'] = __('Your web browser does not support local storage of settings or the quota limit has been reached, some features may not work properly for you. In Safari, such problem is commonly caused by "Private Mode Browsing".');
+$js_messages['strNoLocalStorage'] = __('There was a problem accessing your browser storage, some features may not work properly for you. It is likely that the browser doesn\'t support storage or the quota limit has been reached. In Firefox, corrupted storage can also cause such a problem, clearing your "Offline Website Data" might help. In Safari, such problem is commonly caused by "Private Mode Browsing".');
+// For modals in db_structure.php
+$js_messages['strCopyTablesTo'] = __('Copy tables to');
+$js_messages['strAddPrefix'] = __('Add table prefix');
+$js_messages['strReplacePrefix'] = __('Replace table with prefix');
+$js_messages['strCopyPrefix'] = __('Copy table with prefix');
 
 echo "var PMA_messages = new Array();\n";
 foreach ($js_messages as $name => $js_message) {
@@ -612,19 +719,20 @@ foreach ($js_messages as $name => $js_message) {
 }
 
 /* Calendar */
-echo "var themeCalendarImage = '" . $GLOBALS['pmaThemeImage']
-    . 'b_calendar.png' . "';\n";
+echo "var themeCalendarImage = '" , $GLOBALS['pmaThemeImage']
+    , 'b_calendar.png' , "';\n";
 
 /* Image path */
-echo "var pmaThemeImage = '" . $GLOBALS['pmaThemeImage'] . "';\n";
+echo "var pmaThemeImage = '" , $GLOBALS['pmaThemeImage'] , "';\n";
 
-echo "var mysql_doc_template = '" . PMA_Util::getMySQLDocuURL('%s') . "';\n";
+echo "var mysql_doc_template = '" , PMA\libraries\Util::getMySQLDocuURL('%s')
+    , "';\n";
 
 //Max input vars allowed by PHP.
 $maxInputVars = ini_get('max_input_vars');
 echo 'var maxInputVars = '
-    . (false === $maxInputVars || '' == $maxInputVars ? 'false' : $maxInputVars)
-    . ';' . "\n";
+    , (false === $maxInputVars || '' == $maxInputVars ? 'false' : (int)$maxInputVars)
+    , ';' . "\n";
 
 echo "if ($.datepicker) {\n";
 /* l10n: Display text for calendar close link */
@@ -778,21 +886,67 @@ PMA_printJsValueForFormValidation('remote', __('Please fix this field'));
 PMA_printJsValueForFormValidation('email', __('Please enter a valid email address'));
 PMA_printJsValueForFormValidation('url', __('Please enter a valid URL'));
 PMA_printJsValueForFormValidation('date', __('Please enter a valid date'));
-PMA_printJsValueForFormValidation('dateISO', __('Please enter a valid date ( ISO )'));
+PMA_printJsValueForFormValidation(
+    'dateISO',
+    __('Please enter a valid date ( ISO )')
+);
 PMA_printJsValueForFormValidation('number', __('Please enter a valid number'));
-PMA_printJsValueForFormValidation('creditcard', __('Please enter a valid credit card number'));
+PMA_printJsValueForFormValidation(
+    'creditcard',
+    __('Please enter a valid credit card number')
+);
 PMA_printJsValueForFormValidation('digits', __('Please enter only digits'));
-PMA_printJsValueForFormValidation('equalTo', __('Please enter the same value again'));
-PMA_printJsValueForFormValidation('maxlength', __('Please enter no more than {0} characters'), true);
-PMA_printJsValueForFormValidation('minlength', __('Please enter at least {0} characters'), true);
-PMA_printJsValueForFormValidation('rangelength', __('Please enter a value between {0} and {1} characters long'), true);
-PMA_printJsValueForFormValidation('range', __('Please enter a value between {0} and {1}'), true);
-PMA_printJsValueForFormValidation('max', __('Please enter a value less than or equal to {0}'), true);
-PMA_printJsValueForFormValidation('min', __('Please enter a value greater than or equal to {0}'), true);
+PMA_printJsValueForFormValidation(
+    'equalTo',
+    __('Please enter the same value again')
+);
+PMA_printJsValueForFormValidation(
+    'maxlength',
+    __('Please enter no more than {0} characters'),
+    true
+);
+PMA_printJsValueForFormValidation(
+    'minlength',
+    __('Please enter at least {0} characters'),
+    true
+);
+PMA_printJsValueForFormValidation(
+    'rangelength',
+    __('Please enter a value between {0} and {1} characters long'),
+    true
+);
+PMA_printJsValueForFormValidation(
+    'range',
+    __('Please enter a value between {0} and {1}'),
+    true
+);
+PMA_printJsValueForFormValidation(
+    'max',
+    __('Please enter a value less than or equal to {0}'),
+    true
+);
+PMA_printJsValueForFormValidation(
+    'min',
+    __('Please enter a value greater than or equal to {0}'),
+    true
+);
 /* customed functions */
-PMA_printJsValueForFormValidation('validationFunctionForDateTime', __('Please enter a valid date or time'), true);
-PMA_printJsValueForFormValidation('validationFunctionForHex', __('Please enter a valid HEX input'), true);
-PMA_printJsValueForFormValidation('validationFunctionForFuns', __('Error'), true, false);
+PMA_printJsValueForFormValidation(
+    'validationFunctionForDateTime',
+    __('Please enter a valid date or time'),
+    true
+);
+PMA_printJsValueForFormValidation(
+    'validationFunctionForHex',
+    __('Please enter a valid HEX input'),
+    true
+);
+PMA_printJsValueForFormValidation(
+    'validationFunctionForFuns',
+    __('Error'),
+    true,
+    false
+);
 echo "\n});";
 echo "\n} /* if ($.validator) */";
 ?>
