@@ -731,9 +731,7 @@ if (! defined('PMA_MINIMUM_COMMON')) {
 
         if (! $auth_plugin->authCheck()) {
             /* Force generating of new session on login */
-            if ($token_provided) {
-                PMA_secureSession();
-            }
+            PMA_secureSession();
             $auth_plugin->auth();
         } else {
             $auth_plugin->authSetUser();
@@ -881,7 +879,15 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         }
 
         if (! $controllink) {
-            $controllink = $userlink;
+            /*
+             * Open separate connection for control queries, this is needed
+             * to avoid problems with table locking used in main connection
+             * and phpMyAdmin issuing queries to configuration storage, which
+             * is not locked by that time.
+             */
+            $controllink = $GLOBALS['dbi']->connect(
+                $cfg['Server']['user'], $cfg['Server']['password'], false
+            );
         }
 
         $auth_plugin->storeUserCredentials();
