@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\Partition;
+use PMA\libraries\Table;
 
 /**
  *
@@ -17,15 +19,14 @@ require_once 'libraries/common.inc.php';
 require_once 'libraries/check_user_privileges.lib.php';
 require_once 'libraries/operations.lib.php';
 
-$pma_table = new PMA_Table($GLOBALS['table'], $GLOBALS['db']);
+$pma_table = new Table($GLOBALS['table'], $GLOBALS['db']);
 
 /**
  * Load JavaScript files
  */
-$response = PMA_Response::getInstance();
+$response = PMA\libraries\Response::getInstance();
 $header   = $response->getHeader();
 $scripts  = $header->getScripts();
-$scripts->addFile('functions.js');
 $scripts->addFile('tbl_operations.js');
 
 /**
@@ -44,12 +45,6 @@ $cfgRelation = PMA_getRelationsParam();
  * Gets available MySQL charsets and storage engines
  */
 require_once 'libraries/mysql_charsets.inc.php';
-require_once 'libraries/StorageEngine.class.php';
-
-/**
- * Class for partition management
- */
-require_once 'libraries/Partition.class.php';
 
 // reselect current db (needed in some cases probably due to
 // the calling of relation.lib.php)
@@ -80,9 +75,6 @@ if ($is_aria) {
 $reread_info = false;
 $table_alters = array();
 
-/** @var PMA_String $pmaString */
-$pmaString = $GLOBALS['PMA_String'];
-
 /**
  * If the table has to be moved to some other database
  */
@@ -136,7 +128,7 @@ if (isset($_REQUEST['submitoptions'])) {
     }
 
     if (! empty($_REQUEST['new_tbl_storage_engine'])
-        && /*overload*/mb_strtoupper($_REQUEST['new_tbl_storage_engine']) !== $tbl_storage_engine
+        && mb_strtoupper($_REQUEST['new_tbl_storage_engine']) !== $tbl_storage_engine
     ) {
         $new_tbl_storage_engine = mb_strtoupper($_REQUEST['new_tbl_storage_engine']);
         // reset the globals for the new engine
@@ -168,7 +160,7 @@ if (isset($_REQUEST['submitoptions'])) {
 
     if (count($table_alters) > 0) {
         $sql_query      = 'ALTER TABLE '
-            . PMA_Util::backquote($GLOBALS['table']);
+            . PMA\libraries\Util::backquote($GLOBALS['table']);
         $sql_query     .= "\r\n" . implode("\r\n", $table_alters);
         $sql_query     .= ';';
         $result        .= $GLOBALS['dbi']->query($sql_query) ? true : false;
@@ -197,8 +189,6 @@ if (isset($_REQUEST['submitorderby']) && ! empty($_REQUEST['order_field'])) {
 /**
  * A partition operation has been requested by the user
  */
-$sql_query = '';
-
 if (isset($_REQUEST['submit_partition'])
     && ! empty($_REQUEST['partition_operation'])
 ) {
@@ -215,47 +205,59 @@ if ($reread_info) {
 unset($reread_info);
 
 if (isset($result) && empty($message_to_show)) {
-    // set to success by default, because result set could be empty
-    // (for example, a table rename)
-    $_type = 'success';
     if (empty($_message)) {
-        $_message = $result
-            ? PMA_Message::success(
-                __('Your SQL query has been executed successfully.')
-            )
-            : PMA_Message::error(__('Error'));
-        // $result should exist, regardless of $_message
-        $_type = $result ? 'success' : 'error';
+        if (empty($sql_query)) {
+            $_message = PMA\libraries\Message::success(__('No change'));
+        } else {
+            $_message = $result
+                ? PMA\libraries\Message::success()
+                : PMA\libraries\Message::error();
+        }
 
         if (isset($GLOBALS['ajax_request'])
             && $GLOBALS['ajax_request'] == true
         ) {
-            $response = PMA_Response::getInstance();
-            $response->isSuccess($_message->isSuccess());
+            $response = PMA\libraries\Response::getInstance();
+            $response->setRequestStatus($_message->isSuccess());
             $response->addJSON('message', $_message);
-            $response->addJSON(
-                'sql_query', PMA_Util::getMessage(null, $sql_query)
-            );
+            if (!empty($sql_query)) {
+                $response->addJSON(
+                    'sql_query', PMA\libraries\Util::getMessage(null, $sql_query)
+                );
+            }
             exit;
         }
     }
     if (! empty($warning_messages)) {
-        $_message = new PMA_Message;
+        $_message = new PMA\libraries\Message;
         $_message->addMessages($warning_messages);
         $_message->isError(true);
-        if ($GLOBALS['ajax_request'] == true) {
-            $response = PMA_Response::getInstance();
-            $response->isSuccess(false);
+        if (isset($GLOBALS['ajax_request'])
+            && $GLOBALS['ajax_request'] == true
+        ) {
+            $response = PMA\libraries\Response::getInstance();
+            $response->setRequestStatus(false);
             $response->addJSON('message', $_message);
+            if (!empty($sql_query)) {
+                $response->addJSON(
+                    'sql_query', PMA\libraries\Util::getMessage(null, $sql_query)
+                );
+            }
             exit;
         }
         unset($warning_messages);
     }
 
-    $response->addHTML(
-        PMA_Util::getMessage($_message, $sql_query, $_type)
-    );
-    unset($_message, $_type);
+    if (empty($sql_query)) {
+        $response->addHTML(
+            $_message->getDisplay()
+        );
+    } else {
+        $response->addHTML(
+            PMA\libraries\Util::getMessage($_message, $sql_query)
+        );
+    }
+    unset($_message);
 }
 
 $url_params['goto']
@@ -280,8 +282,7 @@ $hideOrderTable = false;
 // a user-defined clustered index (PRIMARY KEY or NOT NULL UNIQUE index).
 // InnoDB always orders table rows according to such an index if one is present.
 if ($tbl_storage_engine == 'INNODB') {
-    include_once 'libraries/Index.class.php';
-    $indexes = PMA_Index::getFromTable($GLOBALS['table'], $GLOBALS['db']);
+    $indexes = PMA\libraries\Index::getFromTable($GLOBALS['table'], $GLOBALS['db']);
     foreach ($indexes as $name => $idx) {
         if ($name == 'PRIMARY') {
             $hideOrderTable = true;
@@ -310,8 +311,8 @@ if (! $hideOrderTable) {
  */
 $response->addHTML(PMA_getHtmlForMoveTable());
 
-if (/*overload*/mb_strstr($show_comment, '; InnoDB free') === false) {
-    if (/*overload*/mb_strstr($show_comment, 'InnoDB free') === false) {
+if (mb_strstr($show_comment, '; InnoDB free') === false) {
+    if (mb_strstr($show_comment, 'InnoDB free') === false) {
         // only user entered comment
         $comment = $show_comment;
     } else {
@@ -368,7 +369,7 @@ if (! (isset($db_is_system_schema) && $db_is_system_schema)) {
         && ! (isset($db_is_system_schema) && $db_is_system_schema)
     ) {
         $this_sql_query = 'TRUNCATE TABLE '
-            . PMA_Util::backquote($GLOBALS['table']);
+            . PMA\libraries\Util::backquote($GLOBALS['table']);
         $truncate_table_url_params = array_merge(
             $url_params,
             array(
@@ -384,7 +385,7 @@ if (! (isset($db_is_system_schema) && $db_is_system_schema)) {
     }
     if (! (isset($db_is_system_schema) && $db_is_system_schema)) {
         $this_sql_query = 'DROP TABLE '
-            . PMA_Util::backquote($GLOBALS['table']);
+            . PMA\libraries\Util::backquote($GLOBALS['table']);
         $drop_table_url_params = array_merge(
             $url_params,
             array(
@@ -413,8 +414,8 @@ if (! (isset($db_is_system_schema) && $db_is_system_schema)) {
     );
 }
 
-if (PMA_Partition::havePartitioning()) {
-    $partition_names = PMA_Partition::getPartitionNames($db, $table);
+if (Partition::havePartitioning()) {
+    $partition_names = Partition::getPartitionNames($db, $table);
     // show the Partition maintenance section only if we detect a partition
     if (! is_null($partition_names[0])) {
         $response->addHTML(
