@@ -64,10 +64,9 @@ class AuthenticationCookieTest extends PMATestCase
      * @return void
      * @group medium
      */
-    public function testAuth()
+    public function testAuthErrorAJAX()
     {
         $restoreInstance = PMA\libraries\Response::getInstance();
-        // Case 1
 
         $mockResponse = $this->getMockBuilder('PMA\libraries\Response')
             ->disableOriginalConstructor()
@@ -98,8 +97,18 @@ class AuthenticationCookieTest extends PMATestCase
             $this->object->auth()
         );
 
-        // Case 2
+        $attrInstance->setValue($restoreInstance);
+    }
 
+    /**
+     * Test for PMA\libraries\plugins\auth\AuthenticationConfig::auth
+     *
+     * @return void
+     * @group medium
+     */
+    public function testAuthError()
+    {
+        $restoreInstance = PMA\libraries\Response::getInstance();
         $mockResponse = $this->getMockBuilder('PMA\libraries\Response')
             ->disableOriginalConstructor()
             ->setMethods(array('isAjax', 'getFooter', 'getHeader'))
@@ -266,9 +275,18 @@ class AuthenticationCookieTest extends PMATestCase
         );
 
         @unlink('testlogo_right.png');
+        $attrInstance->setValue($restoreInstance);
+    }
 
-        // case 3
-
+    /**
+     * Test for PMA\libraries\plugins\auth\AuthenticationConfig::auth
+     *
+     * @return void
+     * @group medium
+     */
+    public function testAuthCaptcha()
+    {
+        $restoreInstance = PMA\libraries\Response::getInstance();
         $mockResponse = $this->getMockBuilder('PMA\libraries\Response')
             ->disableOriginalConstructor()
             ->setMethods(array('isAjax', 'getFooter', 'getHeader'))
@@ -355,6 +373,9 @@ class AuthenticationCookieTest extends PMATestCase
      */
     public function testAuthHeader()
     {
+        $GLOBALS['cfg']['LoginCookieDeleteAll'] = false;
+        $GLOBALS['cfg']['Servers'] = array(1);
+
         $restoreInstance = PMA\libraries\Response::getInstance();
 
         $mockResponse = $this->getMockBuilder('PMA\libraries\Response')
@@ -362,11 +383,6 @@ class AuthenticationCookieTest extends PMATestCase
             ->setMethods(array('isAjax', 'headersSent', 'header'))
             ->getMock();
 
-        $mockResponse->expects($this->once())
-            ->method('isAjax')
-            ->with()
-            ->will($this->returnValue(false));
-
         $mockResponse->expects($this->any())
             ->method('headersSent')
             ->with()
@@ -380,12 +396,9 @@ class AuthenticationCookieTest extends PMATestCase
         $attrInstance->setAccessible(true);
         $attrInstance->setValue($mockResponse);
 
-        $_REQUEST['old_usr'] = 'user1';
         $GLOBALS['cfg']['Server']['LogoutURL'] = 'http://www.phpmyadmin.net/logout';
 
-        $this->assertTrue(
-            $this->object->auth()
-        );
+        $this->object->logOut();
 
         $attrInstance->setValue($restoreInstance);
     }
@@ -395,21 +408,8 @@ class AuthenticationCookieTest extends PMATestCase
      *
      * @return void
      */
-    public function testAuthCheck()
+    public function testAuthCheckSwekey()
     {
-        $defineAgain = 'PMA_TEST_NO_DEFINE';
-
-        if (defined('PMA_CLEAR_COOKIES')) {
-            if (! PMA_HAS_RUNKIT) {
-                $this->markTestSkipped(
-                    'Cannot redefine constant/function - missing runkit extension'
-                );
-            } else {
-                $defineAgain = PMA_CLEAR_COOKIES;
-                runkit_constant_remove('PMA_CLEAR_COOKIES');
-            }
-        }
-
         $GLOBALS['cfg']['Server']['auth_swekey_config'] = 'testConfigSwekey';
 
         file_put_contents('testConfigSwekey', '');
@@ -417,9 +417,16 @@ class AuthenticationCookieTest extends PMATestCase
             $this->object->authCheck()
         );
         @unlink('testConfigSwekey');
+    }
 
-        // case 2
-
+    /**
+     * Test for PMA\libraries\plugins\auth\AuthenticationConfig::authCheck
+     *
+     * @return void
+     */
+    public function testAuthCheckCaptcha()
+    {
+        $GLOBALS['cfg']['Server']['auth_swekey_config'] = '';
         $GLOBALS['cfg']['CaptchaLoginPrivateKey'] = 'testprivkey';
         $GLOBALS['cfg']['CaptchaLoginPublicKey'] = 'testpubkey';
         $_POST["g-recaptcha-response"] = '';
@@ -433,42 +440,102 @@ class AuthenticationCookieTest extends PMATestCase
             'Please enter correct captcha!',
             $GLOBALS['conn_error']
         );
+    }
 
-        // case 4
+    /**
+     * Test for PMA\libraries\plugins\auth\AuthenticationConfig::authCheck
+     *
+     * @return void
+     */
+    public function testLogoutDelete()
+    {
+        $restoreInstance = PMA\libraries\Response::getInstance();
 
+        $mockResponse = $this->getMockBuilder('PMA\libraries\Response')
+            ->disableOriginalConstructor()
+            ->setMethods(array('isAjax', 'headersSent', 'header'))
+            ->getMock();
+
+        $mockResponse->expects($this->any())
+            ->method('headersSent')
+            ->with()
+            ->will($this->returnValue(false));
+
+        $mockResponse->expects($this->once())
+            ->method('header')
+            ->with('Location: ./index.php' . ((SID) ? '?' . SID : ''));
+
+        $attrInstance = new ReflectionProperty('PMA\libraries\Response', '_instance');
+        $attrInstance->setAccessible(true);
+        $attrInstance->setValue($mockResponse);
+
+        $GLOBALS['cfg']['Server']['auth_swekey_config'] = '';
         $GLOBALS['cfg']['CaptchaLoginPrivateKey'] = '';
         $GLOBALS['cfg']['CaptchaLoginPublicKey'] = '';
-        $_REQUEST['old_usr'] = 'pmaolduser';
         $GLOBALS['cfg']['LoginCookieDeleteAll'] = true;
         $GLOBALS['cfg']['Servers'] = array(1);
 
         $_COOKIE['pmaPass-0'] = 'test';
 
-        $this->object->authCheck();
+        $this->object->logOut();
 
         $this->assertFalse(
             isset($_COOKIE['pmaPass-0'])
         );
+        $attrInstance->setValue($restoreInstance);
+    }
 
-        // case 5
+    /**
+     * Test for PMA\libraries\plugins\auth\AuthenticationConfig::authCheck
+     *
+     * @return void
+     */
+    public function testLogout()
+    {
+        $restoreInstance = PMA\libraries\Response::getInstance();
 
+        $mockResponse = $this->getMockBuilder('PMA\libraries\Response')
+            ->disableOriginalConstructor()
+            ->setMethods(array('isAjax', 'headersSent', 'header'))
+            ->getMock();
+
+        $mockResponse->expects($this->any())
+            ->method('headersSent')
+            ->with()
+            ->will($this->returnValue(false));
+
+        $mockResponse->expects($this->once())
+            ->method('header')
+            ->with('Location: ./index.php' . ((SID) ? '?' . SID : ''));
+
+        $attrInstance = new ReflectionProperty('PMA\libraries\Response', '_instance');
+        $attrInstance->setAccessible(true);
+        $attrInstance->setValue($mockResponse);
+        $GLOBALS['cfg']['Server']['auth_swekey_config'] = '';
         $GLOBALS['cfg']['CaptchaLoginPrivateKey'] = '';
         $GLOBALS['cfg']['CaptchaLoginPublicKey'] = '';
-        $_REQUEST['old_usr'] = 'pmaolduser';
         $GLOBALS['cfg']['LoginCookieDeleteAll'] = false;
         $GLOBALS['cfg']['Servers'] = array(1);
         $GLOBALS['server'] = 1;
 
         $_COOKIE['pmaPass-1'] = 'test';
 
-        $this->object->authCheck();
+        $this->object->logOut();
 
         $this->assertFalse(
             isset($_COOKIE['pmaPass-1'])
         );
+        $attrInstance->setValue($restoreInstance);
+    }
 
-        // case 6
-
+    /**
+     * Test for PMA\libraries\plugins\auth\AuthenticationConfig::authCheck
+     *
+     * @return void
+     */
+    public function testAuthCheckArbitrary()
+    {
+        $GLOBALS['cfg']['Server']['auth_swekey_config'] = '';
         $GLOBALS['cfg']['CaptchaLoginPrivateKey'] = '';
         $GLOBALS['cfg']['CaptchaLoginPublicKey'] = '';
         $_REQUEST['old_usr'] = '';
@@ -499,9 +566,19 @@ class AuthenticationCookieTest extends PMATestCase
         $this->assertFalse(
             isset($_COOKIE['pmaPass-1'])
         );
+    }
 
-        // case 7
-
+    /**
+     * Test for PMA\libraries\plugins\auth\AuthenticationConfig::authCheck
+     *
+     * @return void
+     */
+    public function testAuthCheckIV()
+    {
+        $GLOBALS['cfg']['AllowArbitraryServer'] = true;
+        $GLOBALS['cfg']['Server']['auth_swekey_config'] = '';
+        $_REQUEST['pma_servername'] = 'testPMAServer';
+        $_REQUEST['pma_password'] = 'testPMAPSWD';
         $_REQUEST['pma_username'] = '';
         $GLOBALS['server'] = 1;
         $_COOKIE['pmaServer-1'] = 'pmaServ1';
@@ -516,9 +593,16 @@ class AuthenticationCookieTest extends PMATestCase
             'pmaServ1',
             $GLOBALS['pma_auth_server']
         );
+    }
 
-        // case 8
-
+    /**
+     * Test for PMA\libraries\plugins\auth\AuthenticationConfig::authCheck
+     *
+     * @return void
+     */
+    public function testAuthCheckExpires()
+    {
+        $GLOBALS['cfg']['Server']['auth_swekey_config'] = '';
         $GLOBALS['server'] = 1;
         $_COOKIE['pmaServer-1'] = 'pmaServ1';
         $_COOKIE['pmaUser-1'] = 'pmaUser1';
@@ -531,57 +615,6 @@ class AuthenticationCookieTest extends PMATestCase
         $this->assertFalse(
             $this->object->authCheck()
         );
-
-        if ($defineAgain !== 'PMA_TEST_NO_DEFINE') {
-            define('PMA_CLEAR_COOKIES', $defineAgain);
-        }
-    }
-
-    /**
-     * Test for PMA\libraries\plugins\auth\AuthenticationConfig::authCheck with constant modifications
-     *
-     * @return void
-     */
-    public function testAuthCheckWithConstants()
-    {
-        if (!defined('PMA_CLEAR_COOKIES') && !PMA_HAS_RUNKIT) {
-            $this->markTestSkipped(
-                'Cannot redefine constant/function - missing runkit extension'
-            );
-        }
-
-        $remove = false;
-
-        if (! defined('PMA_CLEAR_COOKIES')) {
-            define('PMA_CLEAR_COOKIES', true);
-            $remove = true;
-        }
-
-        $GLOBALS['cfg']['Server']['auth_swekey_config'] = 'testConfigSwekey';
-        $GLOBALS['cfg']['Servers'] = array(1);
-        $_COOKIE['pmaPass-0'] = 1;
-        $_COOKIE['pmaServer-0'] = 1;
-        $_COOKIE['pmaUser-0'] = 1;
-
-        $this->assertFalse(
-            $this->object->authCheck()
-        );
-
-        $this->assertFalse(
-            isset($_COOKIE['pmaPass-0'])
-        );
-
-        $this->assertFalse(
-            isset($_COOKIE['pmaServer-0'])
-        );
-
-        $this->assertFalse(
-            isset($_COOKIE['pmaUser-0'])
-        );
-
-        if ($remove) {
-            runkit_constant_remove('PMA_CLEAR_COOKIES');
-        }
     }
 
     /**
@@ -876,8 +909,6 @@ class AuthenticationCookieTest extends PMATestCase
         $GLOBALS['server'] = 2;
         $_COOKIE['pmaPass-2'] = 'pass';
 
-        // case 1
-
         $GLOBALS['login_without_password_is_forbidden'] = '1';
 
         $this->doMockResponse(
@@ -895,7 +926,6 @@ class AuthenticationCookieTest extends PMATestCase
 
     public function testAuthFailsDeny()
     {
-        // case 2
         $this->object = $this->getMockBuilder('PMA\libraries\plugins\auth\AuthenticationCookie')
             ->disableOriginalConstructor()
             ->setMethods(array('auth'))
@@ -920,7 +950,6 @@ class AuthenticationCookieTest extends PMATestCase
 
     public function testAuthFailsActivity()
     {
-        // case 3
         $this->object = $this->getMockBuilder('PMA\libraries\plugins\auth\AuthenticationCookie')
             ->disableOriginalConstructor()
             ->setMethods(array('auth'))
@@ -947,7 +976,6 @@ class AuthenticationCookieTest extends PMATestCase
 
     public function testAuthFailsDBI()
     {
-        // case 4
         $this->object = $this->getMockBuilder('PMA\libraries\plugins\auth\AuthenticationCookie')
             ->disableOriginalConstructor()
             ->setMethods(array('auth'))
@@ -982,7 +1010,6 @@ class AuthenticationCookieTest extends PMATestCase
 
     public function testAuthFailsErrno()
     {
-        // case 5
         $this->object = $this->getMockBuilder('PMA\libraries\plugins\auth\AuthenticationCookie')
             ->disableOriginalConstructor()
             ->setMethods(array('auth'))
@@ -1018,7 +1045,7 @@ class AuthenticationCookieTest extends PMATestCase
      *
      * @return void
      */
-    public function testGetEncryptionSecret()
+    public function testGetEncryptionSecretEmpty()
     {
         $method = new \ReflectionMethod(
             'PMA\libraries\plugins\auth\AuthenticationCookie',
@@ -1026,8 +1053,6 @@ class AuthenticationCookieTest extends PMATestCase
         );
         $method->setAccessible(true);
 
-        // case 1
-
         $GLOBALS['cfg']['blowfish_secret'] = '';
         $_SESSION['encryption_key'] = '';
 
@@ -1042,8 +1067,20 @@ class AuthenticationCookieTest extends PMATestCase
             256,
             strlen($result)
         );
+    }
 
-        // case 2
+    /**
+     * Test for PMA\libraries\plugins\auth\AuthenticationConfig::_getEncryptionSecret
+     *
+     * @return void
+     */
+    public function testGetEncryptionSecretConfigured()
+    {
+        $method = new \ReflectionMethod(
+            'PMA\libraries\plugins\auth\AuthenticationCookie',
+            '_getEncryptionSecret'
+        );
+        $method->setAccessible(true);
 
         $GLOBALS['cfg']['blowfish_secret'] = 'notEmpty';
 
