@@ -17,7 +17,7 @@ require_once './libraries/common.inc.php';
  */
 require_once './libraries/server_privileges.lib.php';
 
-$response = PMA_Response::getInstance();
+$response = PMA\libraries\Response::getInstance();
 $header   = $response->getHeader();
 $scripts  = $header->getScripts();
 $scripts->addFile('server_privileges.js');
@@ -30,7 +30,7 @@ if (! $GLOBALS['cfg']['ShowChgPassword']) {
     $GLOBALS['cfg']['ShowChgPassword'] = $GLOBALS['dbi']->selectDb('mysql');
 }
 if ($cfg['Server']['auth_type'] == 'config' || ! $cfg['ShowChgPassword']) {
-    PMA_Message::error(
+    PMA\libraries\Message::error(
         __('You don\'t have sufficient privileges to be here right now!')
     )->display();
     exit;
@@ -85,12 +85,12 @@ function PMA_getChangePassMessage($change_password_message, $sql_query = '')
         /**
          * If in an Ajax request, we don't need to show the rest of the page
          */
-        $response = PMA_Response::getInstance();
+        $response = PMA\libraries\Response::getInstance();
         if ($change_password_message['error']) {
             $response->addJSON('message', $change_password_message['msg']);
-            $response->isSuccess(false);
+            $response->setRequestStatus(false);
         } else {
-            $sql_query = PMA_Util::getMessage(
+            $sql_query = PMA\libraries\Util::getMessage(
                 $change_password_message['msg'],
                 $sql_query,
                 'success'
@@ -109,14 +109,16 @@ function PMA_getChangePassMessage($change_password_message, $sql_query = '')
 function PMA_setChangePasswordMsg()
 {
     $error = false;
-    $message = PMA_Message::success(__('The profile has been updated.'));
+    $message = PMA\libraries\Message::success(__('The profile has been updated.'));
 
     if (($_REQUEST['nopass'] != '1')) {
         if (empty($_REQUEST['pma_pw']) || empty($_REQUEST['pma_pw2'])) {
-            $message = PMA_Message::error(__('The password is empty!'));
+            $message = PMA\libraries\Message::error(__('The password is empty!'));
             $error = true;
         } elseif ($_REQUEST['pma_pw'] != $_REQUEST['pma_pw2']) {
-            $message = PMA_Message::error(__('The passwords aren\'t the same!'));
+            $message = PMA\libraries\Message::error(
+                __('The passwords aren\'t the same!')
+            );
             $error = true;
         }
     }
@@ -138,13 +140,11 @@ function PMA_changePassword($password, $message, $change_password_message)
 
     $hashing_function = PMA_changePassHashingFunction();
 
-    $orig_auth_plugin = null;
-
     $row = $GLOBALS['dbi']->fetchSingleRow('SELECT CURRENT_USER() as user');
     $curr_user = $row['user'];
     list($username, $hostname) = explode('@', $curr_user);
 
-    $serverType = PMA_Util::getServerType();
+    $serverType = PMA\libraries\Util::getServerType();
 
     if (isset($_REQUEST['authentication_plugin'])
         && ! empty($_REQUEST['authentication_plugin'])
@@ -210,14 +210,14 @@ function PMA_changePassHashingFunction()
 }
 
 /**
- * Generate the error url and submit the query
+ * Changes password for a user
  *
- * @param string $username              Username
- * @param string $hostname              Hostname
- * @param string $password              Password
- * @param string $sql_query             SQL query
- * @param string $hashing_function      Hashing function
- * @param string $orig_auth_plugin      Original Authentication Plugin
+ * @param string $username         Username
+ * @param string $hostname         Hostname
+ * @param string $password         Password
+ * @param string $sql_query        SQL query
+ * @param string $hashing_function Hashing function
+ * @param string $orig_auth_plugin Original Authentication Plugin
  *
  * @return void
  */
@@ -225,16 +225,18 @@ function PMA_changePassUrlParamsAndSubmitQuery(
     $username, $hostname, $password, $sql_query, $hashing_function, $orig_auth_plugin
 ) {
     $err_url = 'user_password.php' . PMA_URL_getCommon();
-    $serverType = PMA_Util::getServerType();
+
+    $serverType = PMA\libraries\Util::getServerType();
 
     if ($serverType == 'MySQL' && PMA_MYSQL_INT_VERSION >= 50706) {
         $local_query = 'ALTER USER \'' . $username . '\'@\'' . $hostname . '\''
             . ' IDENTIFIED with ' . $orig_auth_plugin . ' BY '
             . (($password == '')
             ? '\'\''
-            : '\'' . PMA_Util::sqlAddSlashes($password) . '\'');
+            : '\'' . PMA\libraries\Util::sqlAddSlashes($password) . '\'');
     } else if ($serverType == 'MariaDB'
         && PMA_MYSQL_INT_VERSION >= 50200
+        && PMA_MYSQL_INT_VERSION < 100100
     ) {
         if ($orig_auth_plugin == 'mysql_native_password') {
             // Set the hashing method used by PASSWORD()
@@ -259,11 +261,16 @@ function PMA_changePassUrlParamsAndSubmitQuery(
     } else {
         $local_query = 'SET password = ' . (($password == '')
             ? '\'\''
-            : $hashing_function . '(\'' . PMA_Util::sqlAddSlashes($password)
-                . '\')');
+            : $hashing_function . '(\''
+                . PMA\libraries\Util::sqlAddSlashes($password) . '\')');
     }
     if (! @$GLOBALS['dbi']->tryQuery($local_query)) {
-        PMA_Util::mysqlDie($GLOBALS['dbi']->getError(), $sql_query, false, $err_url);
+        PMA\libraries\Util::mysqlDie(
+            $GLOBALS['dbi']->getError(),
+            $sql_query,
+            false,
+            $err_url
+        );
     }
 }
 
@@ -277,12 +284,12 @@ function PMA_changePassUrlParamsAndSubmitQuery(
  */
 function PMA_changePassDisplayPage($message, $sql_query)
 {
-    echo '<h1>' . __('Change password') . '</h1>' . "\n\n";
-    echo PMA_Util::getMessage(
+    echo '<h1>' , __('Change password') , '</h1>' , "\n\n";
+    echo PMA\libraries\Util::getMessage(
         $message, $sql_query, 'success'
     );
-    echo '<a href="index.php' . PMA_URL_getCommon()
-        . ' target="_parent">' . "\n"
-        . '<strong>' . __('Back') . '</strong></a>';
+    echo '<a href="index.php' , PMA_URL_getCommon()
+        , ' target="_parent">' , "\n"
+        , '<strong>' , __('Back') , '</strong></a>';
     exit;
 }
